<?php

namespace Drupal\entity_field_fetch\Plugin\GraphQL\Fields\Entity\Fields\EntityFieldFetch;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use Drupal\entity_field_fetch\Plugin\Field\FieldType\EntityFieldFetchItem;
use GraphQL\Type\Definition\ResolveInfo;
use Drupal\graphql\Utility\StringHelper;

/**
 * Resolve fetched Data to look like GraphQL.
 *
 * @GraphQLField(
 *   id = "fetched",
 *   secure = true,
 *   name = "fetched",
 *   type = "Map",
 *   provider = "entity_field_fetch",
 *   field_types = {"entity_field_fetch"},
 *   deriver = "Drupal\graphql_core\Plugin\Deriver\Fields\EntityFieldPropertyDeriver"
 * )
 */
class EntityFieldFetchFetched extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  protected function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {
    if ($value instanceof EntityFieldFetchItem) {
      $newray = $this->convertKeysToCamel($value->fetched);

      yield $newray;
    }
  }

  /**
   * Alter array keys to camel case. Can be called recursively.
   *
   * @param mixed $item_to_process
   *   Arrays get processed, all other types pass through.
   *
   * @return mixed
   *   Returns the same kind of item that was passed in.
   */
  protected function convertKeysToCamel($item_to_process) {
    if (is_array($item_to_process)) {
      $new_array = [];
      foreach ($item_to_process as $key => $value) {
        $new_key = (is_numeric($key)) ? $key : StringHelper::propCase($key);
        $new_key = $this->mapKey($new_key);
        $new_array[$new_key] = $this->convertKeysToCamel($value);
      }

      if (!empty($item_to_process['type'])) {
        // Assuming this is an entity.
        $entity_wrapper = [
          'entity' => $new_array,
        ];

        return $entity_wrapper;
      }
      return $new_array;

    }
    else {
      return $item_to_process;
    }
  }

  /**
   * Does key replacement of keys differ between Drupal and GraphQL.
   *
   * @param mixed $original_key
   *   The original key.
   *
   * @return mixed
   *   The mapped key if there is one, or the original key.
   */
  protected function mapKey($original_key) {
    $key_map = [
      // Drupal key => graphQL key.
      'bundle' => 'entityBundle',
      'type' => 'entityType',

    ];
    return (!empty($key_map[$original_key])) ? $key_map[$original_key] : $original_key;

  }

}
